import { ButtonSize, ButtonState, ButtonType } from './uitk-button-attributes';
import { EnumValues } from "enum-values";
export class Button {
    constructor() {
        this.buttonType = ButtonType.TextAction;
        this.buttonSize = ButtonSize.Medium;
        this.buttonState = ButtonState.None;
        this.type = "TextAction";
        this.size = "Medium";
        this.state = 'None';
    }
    handleClick(args) {
        this.uitkClick.emit(args);
    }
    componentWillLoad() {
        this.typeDidChangeHandler();
        this.sizeDidChangeHandler();
        this.stateDidChangeHandler();
    }
    getClass() {
        return 'btn ' + this.buttonType + ' ' + this.buttonSize + ' ' + this.buttonState;
    }
    typeDidChangeHandler() {
        if (ButtonType[this.type]) {
            this.buttonType = ButtonType[this.type];
        }
        else {
            this.warnIncorrectValue('type', this.type, this.buttonType, ButtonType);
        }
    }
    sizeDidChangeHandler() {
        if (ButtonSize[this.size] !== undefined) {
            this.buttonSize = ButtonSize[this.size];
        }
        else {
            this.warnIncorrectValue('size', this.size, this.buttonSize, ButtonSize);
        }
    }
    stateDidChangeHandler() {
        if (ButtonState[this.state]) {
            this.buttonState = ButtonState[this.state];
        }
        else {
            this.warnIncorrectValue('state', this.state, this.buttonState, ButtonState);
        }
    }
    warnIncorrectValue(propName, unrecognizedValue, currentValue, enumType) {
        console.warn('Unrecognized value (\'' + unrecognizedValue + '\') specified for property \'' + propName + '\' of button[#' + this.id + ']. ' +
            'Will keep current/default value as ' + EnumValues.getNameFromValue(enumType, currentValue) +
            '. Valid values are ' + Object.keys(enumType));
    }
    render() {
        return h("button", { class: this.getClass(), onClick: (e) => this.handleClick(e) },
            h("span", { class: "btn-label" }, this.label));
    }
    static get is() { return "uitk-button"; }
    static get properties() { return {
        "id": {
            "type": String,
            "attr": "id"
        },
        "label": {
            "type": String,
            "attr": "label"
        },
        "size": {
            "type": String,
            "attr": "size",
            "watchCallbacks": ["sizeDidChangeHandler"]
        },
        "state": {
            "type": String,
            "attr": "state",
            "watchCallbacks": ["stateDidChangeHandler"]
        },
        "type": {
            "type": String,
            "attr": "type",
            "watchCallbacks": ["typeDidChangeHandler"]
        }
    }; }
    static get events() { return [{
            "name": "uitkClick",
            "method": "uitkClick",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }]; }
    static get style() { return "/**style-placeholder:uitk-button:**/"; }
}
