import { h } from '../uitk-button.core.js';

var ButtonType;
(function (ButtonType) {
    ButtonType["Action"] = "btn-action";
    ButtonType["SubAction"] = "btn-sub-action";
    ButtonType["TextAction"] = "btn-text-action";
    ButtonType["TextSubAction"] = "btn-text-sub-action";
    ButtonType["Utility"] = "btn-utility";
    ButtonType["Add"] = "btn-add";
})(ButtonType || (ButtonType = {}));
var ButtonSize;
(function (ButtonSize) {
    ButtonSize["Small"] = "btn-small";
    ButtonSize["Medium"] = "btn-med";
    ButtonSize["Large"] = "btn-large";
})(ButtonSize || (ButtonSize = {}));
var ButtonState;
(function (ButtonState) {
    ButtonState["Disabled"] = "disabled";
    ButtonState["Success"] = "success";
    ButtonState["Error"] = "error";
    ButtonState["Warning"] = "warn";
    ButtonState["None"] = " ";
})(ButtonState || (ButtonState = {}));

function unwrapExports (x) {
	return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, 'default') ? x.default : x;
}

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var enumValues = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });
var EnumValues = (function () {
    function EnumValues() {
    }
    EnumValues.getNamesAndValues = function (e) {
        return this.getNames(e).map(function (_name) { return { name: _name, value: e[_name] }; });
    };
    EnumValues.getNames = function (e) {
        return Object.keys(e).filter(function (key) { return isNaN(+key); });
    };
    EnumValues.getNameFromValue = function (e, value) {
        var all = this.getNamesAndValues(e).filter(function (pair) { return pair.value === value; });
        return all.length == 1 ? all[0].name : null;
    };
    EnumValues.getValues = function (e) {
        return this.getNames(e).map(function (name) { return e[name]; });
    };
    return EnumValues;
}());
exports.EnumValues = EnumValues;
});

unwrapExports(enumValues);
var enumValues_1 = enumValues.EnumValues;

var enumValues$2 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });

exports.EnumValues = enumValues.EnumValues;
});

unwrapExports(enumValues$2);
var enumValues_2 = enumValues$2.EnumValues;

class Button {
    constructor() {
        this.buttonType = ButtonType.TextAction;
        this.buttonSize = ButtonSize.Medium;
        this.buttonState = ButtonState.None;
        this.type = "TextAction";
        this.size = "Medium";
        this.state = 'None';
    }
    handleClick(args) {
        this.uitkClick.emit(args);
    }
    componentWillLoad() {
        this.typeDidChangeHandler();
        this.sizeDidChangeHandler();
        this.stateDidChangeHandler();
    }
    getClass() {
        return 'btn ' + this.buttonType + ' ' + this.buttonSize + ' ' + this.buttonState;
    }
    typeDidChangeHandler() {
        if (ButtonType[this.type]) {
            this.buttonType = ButtonType[this.type];
        }
        else {
            this.warnIncorrectValue('type', this.type, this.buttonType, ButtonType);
        }
    }
    sizeDidChangeHandler() {
        if (ButtonSize[this.size] !== undefined) {
            this.buttonSize = ButtonSize[this.size];
        }
        else {
            this.warnIncorrectValue('size', this.size, this.buttonSize, ButtonSize);
        }
    }
    stateDidChangeHandler() {
        if (ButtonState[this.state]) {
            this.buttonState = ButtonState[this.state];
        }
        else {
            this.warnIncorrectValue('state', this.state, this.buttonState, ButtonState);
        }
    }
    warnIncorrectValue(propName, unrecognizedValue, currentValue, enumType) {
        console.warn('Unrecognized value (\'' + unrecognizedValue + '\') specified for property \'' + propName + '\' of button[#' + this.id + ']. ' +
            'Will keep current/default value as ' + enumValues_2.getNameFromValue(enumType, currentValue) +
            '. Valid values are ' + Object.keys(enumType));
    }
    render() {
        return h("button", { class: this.getClass(), onClick: (e) => this.handleClick(e) },
            h("span", { class: "btn-label" }, this.label));
    }
    static get is() { return "uitk-button"; }
    static get properties() { return {
        "id": {
            "type": String,
            "attr": "id"
        },
        "label": {
            "type": String,
            "attr": "label"
        },
        "size": {
            "type": String,
            "attr": "size",
            "watchCallbacks": ["sizeDidChangeHandler"]
        },
        "state": {
            "type": String,
            "attr": "state",
            "watchCallbacks": ["stateDidChangeHandler"]
        },
        "type": {
            "type": String,
            "attr": "type",
            "watchCallbacks": ["typeDidChangeHandler"]
        }
    }; }
    static get events() { return [{
            "name": "uitkClick",
            "method": "uitkClick",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }]; }
    static get style() { return "button{-webkit-appearance:none;-moz-appearance:none;appearance:none}.btn,.btn:visited,button{display:inline-block;position:relative;border-radius:.13em;padding:0;text-align:center;-webkit-transition:background-color .2s;transition:background-color .2s;line-height:normal;margin:1.2rem 1.2rem 0 0}.btn .btn-label,.btn:visited .btn-label,button .btn-label{position:relative;display:inline-block;pointer-events:none;font-family:Roboto,sans-serif;font-weight:500;text-transform:uppercase;letter-spacing:.6px}.btn .btn-label sup,.btn:visited .btn-label sup,button .btn-label sup{color:#5e778b;top:-6px}.btn-message{font-size:.73rem;margin-top:.27em}.btn-large .btn-label{font-size:1.2rem;padding:1.14em 2.67em 1.14em}.btn-large.btn-add .btn-label,.btn-large.btn-utility .btn-label{padding-top:1.08em;padding-bottom:1.08em}.btn-large.btn-text-action .btn-label,.btn-large.btn-text-sub-action .btn-label{padding-left:2.67em;padding-right:2.67em}\@media only screen and (min-width:0px) and (max-width:540px){.btn-large .btn-label{font-size:.87rem;line-height:1.2;padding:1.27em 2.46em 1.27em}.btn-large.btn-add .btn-label,.btn-large.btn-utility .btn-label{padding-top:1.19em;padding-bottom:1.19em}.btn-large.btn-text-action .btn-label,.btn-large.btn-text-sub-action .btn-label{padding-left:2.46em;padding-right:2.46em}}.btn-med .btn-label{font-size:.87rem;line-height:1.2;padding:1.27em 2.46em 1.27em}.btn-med.btn-add .btn-label,.btn-med.btn-utility .btn-label{padding-top:1.19em;padding-bottom:1.19em}.btn-med.btn-text-action .btn-label,.btn-med.btn-text-sub-action .btn-label{padding-left:2.46em;padding-right:2.46em}.btn-small .btn-label{font-size:.73rem;line-height:1.2;padding:.5em 1.09em .5em}.btn-small.btn-add .btn-label,.btn-small.btn-utility .btn-label{padding-top:.41em;padding-bottom:.41em}.btn-small.btn-text-action .btn-label,.btn-small.btn-text-sub-action .btn-label{padding-left:1.09em;padding-right:1.09em}.btn:hover{text-decoration:none;cursor:pointer}.btn.vtest-focus,.btn:focus{outline:none}.btn-action{border:none;background-color:#3799cf}.btn-action .btn-label{color:#fff}.btn-action:hover{background-color:#2e8bbf}.btn-action.selected,.btn-action:active{background-color:#2178a8}.btn-sub-action{border:none;background-color:#485f71}.btn-sub-action .btn-label{color:#fff}.btn-sub-action:hover{background-color:#344552}.btn-sub-action.selected,.btn-sub-action:active{background-color:#152835}.btn-utility{border:1px solid #bec6cd;background-color:#fff}.btn-utility .btn-label{color:#3799cf}.btn-utility.selected,.btn-utility:active{border:1px solid #3799cf}.btn-add{border:1px dashed #3799cf;background-color:transparent}.btn-add .btn-label{color:#3799cf}.btn-add:hover{border-color:#62b4e1}.btn-add:hover .btn-label{color:#62b4e1}.btn-text-action,.btn-text-sub-action{background:none;border:none}.btn-text-action .btn-label{color:#3799cf}.btn-text-action:hover .btn-label{color:#62b4e1}.btn-text-sub-action .btn-label{color:#485f71}.btn-text-sub-action:hover .btn-label{color:#344552}.btn-round{border-radius:3.33em}.btn-wrapper{display:inline-block}.btn-price{margin:1.6em 1.6em 0 0;font-weight:500;background:#fff;min-width:138px;border:1px solid #dbdfe3;border-radius:.13em}.btn-price:hover{border-color:#bec6cd}.btn-price:hover .btn-label{color:#152835}.btn-price:active{background:#f0f1f3;border:1px solid #bec6cd}.btn-price .btn-label{color:#5e778b;padding:.73em .8em}.btn-price.out-of-policy .icon{color:#e75c5c}.btn-close{margin:0;border:none;background-color:transparent;font-size:1rem;line-height:1.45;color:inherit}.btn-close:active{margin-top:0}.btn-close:after{padding:0 .2em}.btn-close:before{display:block;position:absolute;-webkit-box-sizing:content-box;box-sizing:content-box;top:-.2em;left:-.2em;width:2em;height:2em;content:\"\"}.btn-close .btn-label{padding:0}.btn-close.module-close{background-color:#000;color:#2f5a77}.btn-close.module-close:active,.btn-close.module-close:focus,.btn-close.module-close:hover{background-color:#152835;color:#fff}.btn.disabled,.btn.disabled.vtest-focus,.btn.disabled:focus,.btn.disabled:hover,.btn[disabled],.btn[disabled].vtest-focus,.btn[disabled]:focus,.btn[disabled]:hover{cursor:default;opacity:.8;pointer-events:none;background-color:#bec6cd;background-image:none}.btn.error{background-color:#e75c5c}.btn.error:hover{background-color:#e03030}.btn.error.selected,.btn.error:active{background-color:#b74a4a}.btn.error.disabled,.btn.error[disabled]{background-color:#bec6cd}.btn.success{background-color:#7dcd75}.btn.success:hover{background-color:#5abf50}.btn.success.selected,.btn.success:active{background-color:#5caf54}.btn.success.disabled,.btn.success[disabled]{background-color:#bec6cd}.btn.warn{background-color:#ffc72c}.btn.warn:hover{background-color:#f8b600}.btn.warn.selected,.btn.warn:active{background-color:#e4b636}.btn.warn.disabled,.btn.warn[disabled]{background-color:#bec6cd}.btn.btn-no-margin{margin:0}.col-flush>.input-group>.btn,.col>.input-group>.btn{width:100%}.btn-group{display:inline-block;position:relative}.btn-group>.btn{margin:0 0 0 -.4em;border-radius:0}.btn-group>.btn:first-child{margin-left:0;border-radius:.2em 0 0 .2em}.btn-group>.btn:last-of-type{border-radius:0 .2em .2em 0}.btn-group>.btn:only-of-type{border-radius:.2em}.btn-group .btn-med.btn-utility:active{margin-top:0}.btn-group .icon{padding:0}.btn-group .btn-sub-action.selected,.btn-group.open .btn-sub-action.dropdown-toggle{background-color:#3799cf}.btn-group+.btn-group{margin-left:1.6em}"; }
}

export { Button as UitkButton };
